#!/bin/bash

# Create output directory
mkdir -p output

# Create and use a new builder instance
docker buildx create --name multiarch-builder --use || true

# Build for amd64
docker buildx build --platform linux/amd64 \
    --tag dropshell-static-builder \
    --output type=local,dest=./output/amd64 \
    --target dropshell \
    .

# Build for arm64
docker buildx build --platform linux/arm64 \
    --tag dropshell-static-builder \
    --output type=local,dest=./output/arm64 \
    --target dropshell \
    .

# Move the binaries to the output directory with architecture-specific names
cp output/amd64/dropshell output/dropshell.amd64
cp output/arm64/dropshell output/dropshell.arm64

# Clean up intermediate directories
rm -rf output/amd64 output/arm64

echo "Static binaries have been created:"
ls -la output
